==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_entities/workorder_001/ComplianceDetail.java <==

package net.datastream.schemas.mp_entities.workorder_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ABOVECEILINGPERMIT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INTERIMLIFESAFETY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INTERIMINFECTIONCONTROL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRECONSTRUCTIONRISKASSESSMENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PLANIMPROVEMENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STATEMENTOFCOND" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BUILDMAINTPROGRAM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PERSONALPROTECTIVEEQUIP" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOCKOUT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BURNPERMIT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONFINEDSPACE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PATIENTSAFETY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RECALLNOTICE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SMDA" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HIPAACONFIDENTIALITY" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "aboveceilingpermit",
    "interimlifesafety",
    "interiminfectioncontrol",
    "preconstructionriskassessment",
    "planimprovement",
    "statementofcond",
    "buildmaintprogram",
    "personalprotectiveequip",
    "lockout",
    "burnpermit",
    "confinedspace",
    "patientsafety",
    "recallnotice",
    "smda",
    "hipaaconfidentiality"
})
@XmlRootElement(name = "ComplianceDetail")
public class ComplianceDetail {

    @XmlElement(name = "ABOVECEILINGPERMIT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String aboveceilingpermit;
    @XmlElement(name = "INTERIMLIFESAFETY", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String interimlifesafety;
    @XmlElement(name = "INTERIMINFECTIONCONTROL", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String interiminfectioncontrol;
    @XmlElement(name = "PRECONSTRUCTIONRISKASSESSMENT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String preconstructionriskassessment;
    @XmlElement(name = "PLANIMPROVEMENT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String planimprovement;
    @XmlElement(name = "STATEMENTOFCOND", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String statementofcond;
    @XmlElement(name = "BUILDMAINTPROGRAM", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String buildmaintprogram;
    @XmlElement(name = "PERSONALPROTECTIVEEQUIP", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String personalprotectiveequip;
    @XmlElement(name = "LOCKOUT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String lockout;
    @XmlElement(name = "BURNPERMIT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String burnpermit;
    @XmlElement(name = "CONFINEDSPACE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String confinedspace;
    @XmlElement(name = "PATIENTSAFETY", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String patientsafety;
    @XmlElement(name = "RECALLNOTICE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String recallnotice;
    @XmlElement(name = "SMDA", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String smda;
    @XmlElement(name = "HIPAACONFIDENTIALITY", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String hipaaconfidentiality;

    /**
     * Obtient la valeur de la propriété aboveceilingpermit.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getABOVECEILINGPERMIT() {
        return aboveceilingpermit;
    }

    /**
     * Définit la valeur de la propriété aboveceilingpermit.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setABOVECEILINGPERMIT(String value) {
        this.aboveceilingpermit = value;
    }

    /**
     * Obtient la valeur de la propriété interimlifesafety.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINTERIMLIFESAFETY() {
        return interimlifesafety;
    }

    /**
     * Définit la valeur de la propriété interimlifesafety.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINTERIMLIFESAFETY(String value) {
        this.interimlifesafety = value;
    }

    /**
     * Obtient la valeur de la propriété interiminfectioncontrol.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINTERIMINFECTIONCONTROL() {
        return interiminfectioncontrol;
    }

    /**
     * Définit la valeur de la propriété interiminfectioncontrol.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINTERIMINFECTIONCONTROL(String value) {
        this.interiminfectioncontrol = value;
    }

    /**
     * Obtient la valeur de la propriété preconstructionriskassessment.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRECONSTRUCTIONRISKASSESSMENT() {
        return preconstructionriskassessment;
    }

    /**
     * Définit la valeur de la propriété preconstructionriskassessment.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRECONSTRUCTIONRISKASSESSMENT(String value) {
        this.preconstructionriskassessment = value;
    }

    /**
     * Obtient la valeur de la propriété planimprovement.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPLANIMPROVEMENT() {
        return planimprovement;
    }

    /**
     * Définit la valeur de la propriété planimprovement.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPLANIMPROVEMENT(String value) {
        this.planimprovement = value;
    }

    /**
     * Obtient la valeur de la propriété statementofcond.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSTATEMENTOFCOND() {
        return statementofcond;
    }

    /**
     * Définit la valeur de la propriété statementofcond.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSTATEMENTOFCOND(String value) {
        this.statementofcond = value;
    }

    /**
     * Obtient la valeur de la propriété buildmaintprogram.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBUILDMAINTPROGRAM() {
        return buildmaintprogram;
    }

    /**
     * Définit la valeur de la propriété buildmaintprogram.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBUILDMAINTPROGRAM(String value) {
        this.buildmaintprogram = value;
    }

    /**
     * Obtient la valeur de la propriété personalprotectiveequip.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPERSONALPROTECTIVEEQUIP() {
        return personalprotectiveequip;
    }

    /**
     * Définit la valeur de la propriété personalprotectiveequip.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPERSONALPROTECTIVEEQUIP(String value) {
        this.personalprotectiveequip = value;
    }

    /**
     * Obtient la valeur de la propriété lockout.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOCKOUT() {
        return lockout;
    }

    /**
     * Définit la valeur de la propriété lockout.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOCKOUT(String value) {
        this.lockout = value;
    }

    /**
     * Obtient la valeur de la propriété burnpermit.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBURNPERMIT() {
        return burnpermit;
    }

    /**
     * Définit la valeur de la propriété burnpermit.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBURNPERMIT(String value) {
        this.burnpermit = value;
    }

    /**
     * Obtient la valeur de la propriété confinedspace.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCONFINEDSPACE() {
        return confinedspace;
    }

    /**
     * Définit la valeur de la propriété confinedspace.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCONFINEDSPACE(String value) {
        this.confinedspace = value;
    }

    /**
     * Obtient la valeur de la propriété patientsafety.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPATIENTSAFETY() {
        return patientsafety;
    }

    /**
     * Définit la valeur de la propriété patientsafety.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPATIENTSAFETY(String value) {
        this.patientsafety = value;
    }

    /**
     * Obtient la valeur de la propriété recallnotice.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRECALLNOTICE() {
        return recallnotice;
    }

    /**
     * Définit la valeur de la propriété recallnotice.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRECALLNOTICE(String value) {
        this.recallnotice = value;
    }

    /**
     * Obtient la valeur de la propriété smda.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSMDA() {
        return smda;
    }

    /**
     * Définit la valeur de la propriété smda.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSMDA(String value) {
        this.smda = value;
    }

    /**
     * Obtient la valeur de la propriété hipaaconfidentiality.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHIPAACONFIDENTIALITY() {
        return hipaaconfidentiality;
    }

    /**
     * Définit la valeur de la propriété hipaaconfidentiality.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHIPAACONFIDENTIALITY(String value) {
        this.hipaaconfidentiality = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/workorder_001/ComplianceDetail.java <==

package net.datastream.schemas.mp_entities.workorder_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ABOVECEILINGPERMIT" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}INTERIMLIFESAFETY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}INTERIMINFECTIONCONTROL" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PRECONSTRUCTIONRISKASSESSMENT" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PLANIMPROVEMENT" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}STATEMENTOFCOND" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}BUILDMAINTPROGRAM" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PERSONALPROTECTIVEEQUIP" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LOCKOUT" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}BURNPERMIT" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CONFINEDSPACE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PATIENTSAFETY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}RECALLNOTICE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SMDA" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}HIPAACONFIDENTIALITY" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "aboveceilingpermit",
    "interimlifesafety",
    "interiminfectioncontrol",
    "preconstructionriskassessment",
    "planimprovement",
    "statementofcond",
    "buildmaintprogram",
    "personalprotectiveequip",
    "lockout",
    "burnpermit",
    "confinedspace",
    "patientsafety",
    "recallnotice",
    "smda",
    "hipaaconfidentiality"
})
@XmlRootElement(name = "ComplianceDetail")
public class ComplianceDetail {

    @XmlElement(name = "ABOVECEILINGPERMIT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String aboveceilingpermit;
    @XmlElement(name = "INTERIMLIFESAFETY", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String interimlifesafety;
    @XmlElement(name = "INTERIMINFECTIONCONTROL", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String interiminfectioncontrol;
    @XmlElement(name = "PRECONSTRUCTIONRISKASSESSMENT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String preconstructionriskassessment;
    @XmlElement(name = "PLANIMPROVEMENT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String planimprovement;
    @XmlElement(name = "STATEMENTOFCOND", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String statementofcond;
    @XmlElement(name = "BUILDMAINTPROGRAM", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String buildmaintprogram;
    @XmlElement(name = "PERSONALPROTECTIVEEQUIP", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String personalprotectiveequip;
    @XmlElement(name = "LOCKOUT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String lockout;
    @XmlElement(name = "BURNPERMIT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String burnpermit;
    @XmlElement(name = "CONFINEDSPACE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String confinedspace;
    @XmlElement(name = "PATIENTSAFETY", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String patientsafety;
    @XmlElement(name = "RECALLNOTICE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String recallnotice;
    @XmlElement(name = "SMDA", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String smda;
    @XmlElement(name = "HIPAACONFIDENTIALITY", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String hipaaconfidentiality;

    /**
     * Gets the value of the aboveceilingpermit property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getABOVECEILINGPERMIT() {
        return aboveceilingpermit;
    }

    /**
     * Sets the value of the aboveceilingpermit property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setABOVECEILINGPERMIT(String value) {
        this.aboveceilingpermit = value;
    }

    /**
     * Gets the value of the interimlifesafety property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINTERIMLIFESAFETY() {
        return interimlifesafety;
    }

    /**
     * Sets the value of the interimlifesafety property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINTERIMLIFESAFETY(String value) {
        this.interimlifesafety = value;
    }

    /**
     * Gets the value of the interiminfectioncontrol property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINTERIMINFECTIONCONTROL() {
        return interiminfectioncontrol;
    }

    /**
     * Sets the value of the interiminfectioncontrol property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINTERIMINFECTIONCONTROL(String value) {
        this.interiminfectioncontrol = value;
    }

    /**
     * Gets the value of the preconstructionriskassessment property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRECONSTRUCTIONRISKASSESSMENT() {
        return preconstructionriskassessment;
    }

    /**
     * Sets the value of the preconstructionriskassessment property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRECONSTRUCTIONRISKASSESSMENT(String value) {
        this.preconstructionriskassessment = value;
    }

    /**
     * Gets the value of the planimprovement property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPLANIMPROVEMENT() {
        return planimprovement;
    }

    /**
     * Sets the value of the planimprovement property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPLANIMPROVEMENT(String value) {
        this.planimprovement = value;
    }

    /**
     * Gets the value of the statementofcond property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSTATEMENTOFCOND() {
        return statementofcond;
    }

    /**
     * Sets the value of the statementofcond property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSTATEMENTOFCOND(String value) {
        this.statementofcond = value;
    }

    /**
     * Gets the value of the buildmaintprogram property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBUILDMAINTPROGRAM() {
        return buildmaintprogram;
    }

    /**
     * Sets the value of the buildmaintprogram property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBUILDMAINTPROGRAM(String value) {
        this.buildmaintprogram = value;
    }

    /**
     * Gets the value of the personalprotectiveequip property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPERSONALPROTECTIVEEQUIP() {
        return personalprotectiveequip;
    }

    /**
     * Sets the value of the personalprotectiveequip property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPERSONALPROTECTIVEEQUIP(String value) {
        this.personalprotectiveequip = value;
    }

    /**
     * Gets the value of the lockout property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOCKOUT() {
        return lockout;
    }

    /**
     * Sets the value of the lockout property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOCKOUT(String value) {
        this.lockout = value;
    }

    /**
     * Gets the value of the burnpermit property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBURNPERMIT() {
        return burnpermit;
    }

    /**
     * Sets the value of the burnpermit property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBURNPERMIT(String value) {
        this.burnpermit = value;
    }

    /**
     * Gets the value of the confinedspace property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCONFINEDSPACE() {
        return confinedspace;
    }

    /**
     * Sets the value of the confinedspace property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCONFINEDSPACE(String value) {
        this.confinedspace = value;
    }

    /**
     * Gets the value of the patientsafety property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPATIENTSAFETY() {
        return patientsafety;
    }

    /**
     * Sets the value of the patientsafety property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPATIENTSAFETY(String value) {
        this.patientsafety = value;
    }

    /**
     * Gets the value of the recallnotice property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRECALLNOTICE() {
        return recallnotice;
    }

    /**
     * Sets the value of the recallnotice property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRECALLNOTICE(String value) {
        this.recallnotice = value;
    }

    /**
     * Gets the value of the smda property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSMDA() {
        return smda;
    }

    /**
     * Sets the value of the smda property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSMDA(String value) {
        this.smda = value;
    }

    /**
     * Gets the value of the hipaaconfidentiality property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHIPAACONFIDENTIALITY() {
        return hipaaconfidentiality;
    }

    /**
     * Sets the value of the hipaaconfidentiality property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHIPAACONFIDENTIALITY(String value) {
        this.hipaaconfidentiality = value;
    }

}
